"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TvShowsEndpoint = void 0;
const base_1 = require("./base");
const utils_1 = require("../utils");
const BASE_TV = '/tv';
class TvShowsEndpoint extends base_1.BaseEndpoint {
    constructor(accessToken) {
        super(accessToken);
        this.accessToken = accessToken;
    }
    async details(id) {
        return await this.api.get(`${BASE_TV}/${id}`);
    }
    async alternativeTitles(id) {
        return await this.api.get(`${BASE_TV}/${id}/alternative_titles`);
    }
    async changes(id, options) {
        const params = (0, utils_1.parseOptions)(options);
        return await this.api.get(`${BASE_TV}/${id}/changes?${params}`);
    }
    async contentRatings(id) {
        return await this.api.get(`${BASE_TV}/${id}/content_ratings`);
    }
    async credits(id) {
        return await this.api.get(`${BASE_TV}/${id}/credits`);
    }
    async season(tvId, seasonNumber) {
        return await this.api.get(`${BASE_TV}/${tvId}/season/${seasonNumber}`);
    }
    async episodeGroups(id) {
        return await this.api.get(`${BASE_TV}/${id}/episode_groups`);
    }
    async externalIds(id) {
        return await this.api.get(`${BASE_TV}/${id}/external_ids`);
    }
    async images(id) {
        return await this.api.get(`${BASE_TV}/${id}/images`);
    }
    async keywords(id) {
        return await this.api.get(`${BASE_TV}/${id}/keywords`);
    }
    async recommendations(id, options) {
        const params = (0, utils_1.parseOptions)(options);
        return await this.api.get(`${BASE_TV}/${id}/recommendations?${params}`);
    }
    async reviews(id, options) {
        const params = (0, utils_1.parseOptions)(options);
        return await this.api.get(`${BASE_TV}/${id}/reviews?${params}`);
    }
    async screenedTheatrically(id) {
        return await this.api.get(`${BASE_TV}/${id}/screened_theatrically`);
    }
    async similar(id, options) {
        const params = (0, utils_1.parseOptions)(options);
        return await this.api.get(`${BASE_TV}/${id}/similar?${params}`);
    }
    async translations(id) {
        return await this.api.get(`${BASE_TV}/${id}/translations`);
    }
    async videos(id) {
        return await this.api.get(`${BASE_TV}/${id}/videos`);
    }
    /**
     * Powered by JustWatch
     * @param id
     */
    async watchProviders(id) {
        return await this.api.get(`${BASE_TV}/${id}/watch/providers`);
    }
    async latest() {
        return await this.api.get(`${BASE_TV}/latest`);
    }
    async onTheAir() {
        return await this.api.get(`${BASE_TV}/on_the_air`);
    }
    async airingToday(options) {
        const params = (0, utils_1.parseOptions)(options);
        return await this.api.get(`${BASE_TV}/airing_today?${params}`);
    }
    async popular(options) {
        const params = (0, utils_1.parseOptions)(options);
        return await this.api.get(`${BASE_TV}/popular?${params}`);
    }
    async topRated(options) {
        const params = (0, utils_1.parseOptions)(options);
        return await this.api.get(`${BASE_TV}/top_rated?${params}`);
    }
}
exports.TvShowsEndpoint = TvShowsEndpoint;
//# sourceMappingURL=tv-shows.js.map